LoginManagerConnection

Struct LoginManagerConnection 

pub struct LoginManagerConnection<'a> { /* private fields */ }
An established connection path for the login manager, through which the API is made accessible.

Implementations

Source

impl<'a> LoginManagerConnection<'a>

pub fn inhibit( &self, what: &str, who: &str, why: &str, mode: &str, ) -> Result<OwnedFd, Error>

Inhibit is the only API necessary to take a lock. It takes four arguments:

  • What is a colon-separated list of lock types, i.e. shutdown, sleep, idle, handle-power-key, handle-suspend-key, handle-hibernate-key, handle-lid-switch. Example: “shutdown:idle”
  • Who is a human-readable, descriptive string of who is taking the lock. Example: “Package Updater”
  • Why is a human-readable, descriptive string of why the lock is taken. Example: “Package Update in Progress”
  • Mode is one of block or delay.
Notes

A root user session cannot use systemd inhibitors.

pub fn inhibit_suspend(&self, who: &str, why: &str) -> Result<OwnedFd, Error>

Convenience method for inhibiting suspend.

Equivalent to connection.inhibit("idle:shutdown:sleep", who, why, "block").